@@ -48,7 +48,7 @@ has 'distvname'           => ( is => 'rw' );
 has 'filename'            => ( is => 'rw' );
 has 'index' => ( is => 'rw', isa => 'CPAN::Mini::Webserver::Index' );
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 sub service_name {
     "$ENV{USER}'s minicpan_webserver";
@@ -463,9 +463,7 @@ sub file_page {
     my $contents = $self->get_file_from_tarball( $distribution, $filename );
 
     my $parser = Pod::Simple::HTML->new;
-    my $port   = $self->port;
-    my $host   = $self->hostname;
-    $parser->perldoc_url_prefix("http://$host:$port/perldoc?");
+    $parser->perldoc_url_prefix('/perldoc?');
     $parser->index(0);
     $parser->no_whining(1);
     $parser->no_errata_section(1);
@@ -554,11 +552,9 @@ sub raw_page {
         $_ =~ s{<br>}{}g foreach @lines;
 
         # link module names to ourselves
-        my $port = $self->port;
-        my $host = $self->hostname;
         @lines = map {
             $_
-                =~ s{<span class="word">([^<]+?::[^<]+?)</span>}{<span class="word"><a href="http://$host:$port/perldoc?$1">$1</a></span>};
+                =~ s{<span class="word">([^<]+?::[^<]+?)</span>}{<span class="word"><a href="/perldoc?$1">$1</a></span>}g;
             $_;
         } @lines;
         $html = join '', @lines;
@@ -607,9 +603,7 @@ sub package_page {
     $postfix .= '.pm';
     my ($filename) = grep { $_ =~ /$postfix$/ }
         sort { length($a) <=> length($b) } @filenames;
-    my $port = $self->port;
-    my $host = $self->hostname;
-    my $url  = "http://$host:$port/~$pauseid/$distvname/$filename";
+    my $url  = "/~$pauseid/$distvname/$filename";
 
     $self->redirect($url);
 }
@@ -672,13 +666,13 @@ CPAN::Mini::Webserver - Search and browse Mini CPAN
 =head1 SYNOPSIS
 
   % minicpan_webserver
-  
+
 =head1 DESCRIPTION
 
 This module is the driver that provides a web server that allows
 you to search and browse Mini CPAN. First you must install
 CPAN::Mini and create a local copy of CPAN using minicpan.
-Then you may run minicpan_webserver and search and 
+Then you may run minicpan_webserver and search and
 browse Mini CPAN at http://localhost:2963/.
 
 You may access the Subversion repository at:
@@ -699,5 +693,5 @@ Copyright (C) 2008, Leon Brocard.
 
 =head1 LICENSE
 
-This module is free software; you can redistribute it or 
+This module is free software; you can redistribute it or
 modify it under the same terms as Perl itself.
